pilot.impl.pilot_manager.ComputeDataService

Package pilot :: Package impl :: Module pilot_manager :: Class ComputeDataService |

# Class ComputeDataService

source code

ComputeDataService (CDS).

The ComputeDataService is the application's interface to submit ComputeUnits and PilotData/DataUnit to the Pilot-Manager in the P* Model.

Instance Methods
__init__(self, cds_url=None) Create a ComputeDataService object. | source code
add_pilot_compute_service(self, pcs) Add a PilotComputeService to this CDS. | source code
remove_pilot_compute_service(self, pcs) Remove a PilotJobService from this CDS. | source code
submit_compute_unit(self, compute_unit_description) Submit a CU to this Compute Data Service. | source code
list_pilot_compute(self) List all pilot compute of CDS | source code
add_pilot_data_service(self, pds) Add a PilotDataService | source code
remove_pilot_data_service(self, pds) Remove a PilotDataService | source code
list_pilot_data(self) List all pilot data of CDS | source code
list_data_units(self) List all DUs of CDS | source code
get_data_unit(self, du_id) | source code
submit_data_unit(self, data_unit_description) creates a data unit object and binds it to a physical resource (a pilotdata) | source code
cancel(self) Cancel the CDS. | source code
wait(self) Waits for CUs and DUs. | source code
get_state(self) Returns: State of the ComputeDataService | source code
get_id(self) Returns: id of ComputeDataService | source code
__del__(self) Make sure that background thread terminates | source code
add_pilot_job_service(self, pjs) Add a PilotComputeService to this WUS. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
create_pilot(self, pilot_data_description) Create a PilotData (Inherited from pilot.api.data.api.PilotDataService) | source code
list_pilots(self) List all PDs of PDS (Inherited from pilot.api.data.api.PilotDataService) | source code
remove_pilot_job_service(self, pjs) Remove a PilotComputeService from this WUS. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| CDS_ID_PREFIX = ``'``cds-``'``

Properties
| id (Inherited from pilot.api.data.api.PilotDataService)
| pilot_data (Inherited from pilot.api.data.api.PilotDataService)
| state (Inherited from pilot.api.data.api.PilotDataService)
Inherited from `object`: `__class__`

Method Details

### __init__(self, cds_url=None) (Constructor) | source code
Create a ComputeDataService object. Keyword arguments: cds_url -- Reconnect to an existing CDS (optional). Overrides: object.__init__

### add_pilot_compute_service(self, pcs) | source code
Add a PilotComputeService to this CDS. Parameters: `pcs` - The PilotComputeService to which this ComputeDataService will connect.

### remove_pilot_compute_service(self, pcs) | source code
Remove a PilotJobService from this CDS. Note that it won't cancel the PilotComputeService, it will just no longer be connected to this CDS. Keyword arguments: Parameters: `pcs` - The PilotComputeService to remove from this ComputeDataService.

### submit_compute_unit(self, compute_unit_description) | source code
Submit a CU to this Compute Data Service. Parameters: `compute_unit_description` - The ComputeUnitDescription from the application Returns: ComputeUnit object Overrides: api.compute.api.ComputeUnitService.submit_compute_unit

### add_pilot_data_service(self, pds) | source code
Add a PilotDataService Parameters: `pds` - The PilotDataService to add.

### remove_pilot_data_service(self, pds) | source code
Remove a PilotDataService Parameters: `pds` - The PilotDataService to remove

### cancel(self) | source code
Cancel the CDS. All associated PD and PC objects are canceled. Overrides: api.data.api.PilotDataService.cancel

### wait(self) | source code
Waits for CUs and DUs. Return after all DU's have been placed (i.e. in state Running) and all CU's have been completed (i.e. in state Done) or if a fault has occurred or the user has cancelled a CU or DU.

### get_state(self) | source code
Returns: State of the ComputeDataService Overrides: api.compute.api.ComputeUnitService.get_state

### get_id(self) | source code
Returns: id of ComputeDataService Overrides: api.compute.api.ComputeUnitService.get_id